@@ -80,7 +80,7 @@ INSTALLED_APPS = (
     'allauth.socialaccount.providers.stackexchange',
 
     # Dev only dependencies. Do not include in any production site.
-    'debug_toolbar',
+    # 'debug_toolbar',
 )
 
 
@@ -88,7 +88,7 @@ MIDDLEWARE = (
     'django.middleware.security.SecurityMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
     # NOTE: Do not include DebugToolbarMiddleware in any production site.
-    'debug_toolbar.middleware.DebugToolbarMiddleware',
+    # 'debug_toolbar.middleware.DebugToolbarMiddleware',
     'django.middleware.common.CommonMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.contrib.auth.middleware.AuthenticationMiddleware',
@@ -445,7 +445,7 @@ LOGGING = {
 # When DEBUG is True, don't actually send emails to the SMTP server, just store
 # them in a directory. This way you won't accidentally spam your mailing-lists
 # while you're fiddling with the code.
-if DEBUG == True:
+if DEBUG:
     EMAIL_BACKEND = 'django.core.mail.backends.filebased.EmailBackend'
     EMAIL_FILE_PATH = '/var/lib/hyperkitty/emails'
 
